@@ -171,5 +171,7 @@ async def cancel_tasks(tasks):
             logger.debug("Task cancelled cleanly")
         except asyncio.CancelledError:
             logger.debug("Caught CancelledError for %s", basic.task_name(task))
+        except Exception as e:
+            pass
 
     logger.debug("exit")
