@@ -1,4 +1,8 @@
+import logging
+
 import click
+import klogs
+
 import aiocells.demo_1
 import aiocells.demo_2
 import aiocells.demo_3
@@ -21,8 +25,15 @@ import aiocells.demo_20
 
 
 @click.group()
-def main():
-    pass
+@click.option("--log-line-no", default=False)
+@click.option("--log-level", type=str, default=logging.INFO)
+@click.option("--log-file", type=str, default=None)
+def main(log_line_no, log_file, log_level):
+    klogs.configure_logging(
+        level=log_level,
+        with_line_no=log_line_no,
+        log_file=log_file,
+    )
 
 
 @main.command()
@@ -101,8 +112,9 @@ def demo_15():
 
 
 @main.command()
-def demo_16():
-    aiocells.demo_16.main()
+@click.option("--iterations", type=int)
+def demo_16(iterations):
+    aiocells.demo_16.main(iterations)
 
 
 @main.command()
